#
# spec file for package wondershaper
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           wondershaper
Version:        1.4.1+git.20211015
Release:        1.7
Summary:        A network QoS (Quality of Service) script
License:        GPL-2.0-or-later
Group:          Productivity/Networking/System
URL:            https://github.com/magnific0/wondershaper
Source0:        %{name}-%{version}.tar.xz
# PATCH-FIX-OPENSUSE wondershaper-fix-conf-path.patch -- Use /etc/wondershaper for wondershaper.conf place
Patch0:         wondershaper-fix-conf-path.patch
# PATCH-FIX-OPENSUSE wondershaper-systemd-hardening.patch -- Added hardening to systemd service(s) (bsc#1181400)
Patch1:         wondershaper-systemd-hardening.patch
BuildRequires:  systemd-rpm-macros
Requires:       iproute2
BuildArch:      noarch

%description
Many cablemodem and ADSL users experience horrifying latency while
uploading or downloading. They also notice that uploading hampers
downloading greatly. The wondershaper neatly addresses these issues,
allowing users of a router with a wondershaper to continue using SSH
over a loaded link happily.

%prep
%autosetup

# Fix E: env-script-interpreter (Badness: 9) 
sed -i 's|/usr/bin/env bash|/usr/bin/bash|' %{name}

%build

%install
install -pDm 755 %{name} %{buildroot}/%{_sbindir}/%{name}
install -pDm 644 %{name}.service %{buildroot}/%{_unitdir}/%{name}.service
install -pDm 644 %{name}.conf %{buildroot}/%{_sysconfdir}/%{name}/%{name}.conf

%pre
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%license COPYING
%doc ChangeLog README.bhubert README.md VERSION
%{_sbindir}/%{name}
%{_unitdir}/%{name}.service
%dir %{_sysconfdir}/%{name}
%config %{_sysconfdir}/%{name}/%{name}.conf

%changelog
* Sat Mar 12 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 1.4.1+git.20211015
  - use Debian systemd paths
  - add high priority host support
- Changes since version 1.4
  - download limiting has been added from (removed in 1.3), it had
    to be reworked the script now directs ingress to ifb virtual
    interface where it is properly limited.
    Source for this work are:
  - https://gist.github.com/ole1986/d9d6be5218affd41796610a35e3b069c
  - https://wiki.archlinux.org/index.php/advanced_traffic_control
  - make upload or download limiting optional
- Changes since version 1.3
  - move from CBQ to HTB queuing.
    CBQ didn't cope well on a ~100Mbps link : individual downloads
    were ceiling at 3Mbit/s. Moving to HTB allows to really use all
    the available bandwidth, event with a single TCP connection,
    and without any caveats on SIP telephony or link reactivity.
- Changes since version 1.2
  - added command-line interface (through options and flags)
    that didn't seem to be working before as the options were
    hardcoded in the script.
- Run spec-cleaner
- Update project URL
- Drop rcwondershaper, wondershaper.service, wondershaper-1.1a.diff
- Drop sysconfig.wondershaper, wondershaper comes now itself with
  a .conf file for configuration
- Add wondershaper-fix-conf-path.patch: using /etc/wondershaper
  instead /etc/systemd
- Add _service files
- Add wondershaper-systemd-hardening.patch: bsc#1181400
* Wed Jan  5 2022 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * wondershaper.service
* Wed Mar 20 2019 Jan Engelhardt <jengelh@inai.de>
- Remove name repetition from summary (rpmlint warning)
- %%service_* mandates systemd-rpm-macros and
  should make use of %%systemd_ordering.
- Replace old $RPM_* shell vars.
- Remove author list from description.
* Wed Mar 20 2019 josef.moellers@suse.com
- Added systemd support
  [bsc#1116052, wondershaper.service]
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Thu Mar 30 2017 meissner@suse.com
- prereq %%insserv_prereq
* Sat Nov 15 2014 Led <ledest@gmail.com>
- fix bashism in rcwondershaper script
* Sun Oct  5 2014 jengelh@inai.de
- Remove unused/ancient rpm tags and section
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Sep 29 2004 hvogel@suse.de
- fixed another bug in the init script status behaviour.
  (Bug #46425)
* Fri Aug 27 2004 lmuelle@suse.de
- Add WSHAPER_QDISC_TYPE variable to the sysconfig file and use HTB as
  default.
* Wed Apr 28 2004 hvogel@suse.de
- Do sanity checks only during starting. (Bug #39583)
* Tue Apr 27 2004 hvogel@suse.de
- fix sysconfig variable namings which made config nearly impossible
  (Bug #39464)
* Thu Mar 18 2004 hvogel@suse.de
- fix init script. There is now a default queue so status returned
  always running. (Bug #36510)
* Thu Nov 13 2003 hvogel@suse.de
- dont build as root
* Thu Aug 14 2003 hvogel@suse.de
- Add sysconfig activation metadata
* Thu Jul 31 2003 hvogel@suse.de
- use preun/postun service macros
* Thu Mar 13 2003 hvogel@suse.de
- cleaned patch. wshaper.htb had old variables (#25228)
* Tue Mar  4 2003 hvogel@suse.de
- added QOS kernel test
- fixed sysconfig metadata types
* Sun Jan 26 2003 hvogel@suse.de
- Removed need for src/dst variables reported by axboe
- Source sysconfig file in init script
* Fri Jan 17 2003 hvogel@suse.de
- fixed permissions of init script
- added new sysconfig scheme
* Mon Jan 13 2003 hvogel@suse.de
- Changed variable names to use the original wondershaper names
- Made the verbose rcwondershaper status output variable dependent.
* Thu Dec 19 2002 hvogel@suse.de
- Initial Package, Version 1.1a
